Nest

Struct Nest 

pub struct Nest { /* private fields */ }

Implementations

Source

impl Nest

pub fn new(actual_reporter: Box<dyn Reporter>) -> Self

pub fn with_total(outer_total: f32, actual_reporter: Box<dyn Reporter>) -> Self

pub fn start_phase( &mut self, frac: f32, phase_prefix: Option<String>, item_desc: Cow<'_, str>, )

Starts an outer phase which is frac of the whole

From now on, when reports are issued, the inner phases are each mapped to the range “now” to “now” frac